import numpy as np
import matplotlib.pyplot as plt
import pandas as pd
import seaborn as sns

# https://www.dataquest.io/blog/excel-and-pandas/ For a good explanation on how to use Pandas for Excell

def plot_ChiT(folder,compound,axis, color, label):

	T    = []
	ChiT = []
	
	with open(folder+'/'+folder+'.out', 'r') as f:
		for line in f:
			if line.find('CALCULATION OF THE MAGNETIC SUSCEPTIBILITY') != -1:
				for i in xrange(14):
					line = next(f)
				while True:
					T.append(    float(line.split()[1]) )
					ChiT.append( float(line.split()[7]) )
					line = next(f)	
					if line == '\n':
						break

	axis.plot(T, ChiT, lw=1.0, color=color)

	T = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 'Sheet1', index_col=None, na_values=['NA'], usecols = "C") )
	ChiT = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 'Sheet1', index_col=None, na_values=['NA'], usecols = "J") )

	axis.plot(T, ChiT,lw=0.,marker='o',markerfacecolor='None',markeredgecolor=color,c=color,markersize=4)
	
	if axis == ax1:
		xlim = np.array([0,300])
	elif axis == ax2:
		xlim = np.array([0,300])
	
	axis.set_xlim(xlim)

	return 
	

def plot_Mag(folder_1,compound_1,folder_2,compound_2):

	fig, (ax1,ax2) = plt.subplots( 1,2, sharex=True, sharey=False, figsize=(5.85,4))

	Field  = []
	Mag_2K = []
	Mag_4K = []
	with open(folder_1+'/'+compound_1+'.out', 'r') as f:
		for line in f:
			if line.find('HIGH-FIELD POWDER MAGNETIZATION') != -1:
				for i in xrange(6):
					line = next(f)
				while True:
					Field.append( float(line.split()[0]) )
					Mag_2K.append( float(line.split()[6]) )
					Mag_4K.append( float(line.split()[8]) )
					line = next(f)	
					if line.find('--|---------------|--') != -1:
						break

	ax1.plot(Field,Mag_2K,lw=1.,color='b')
	ax1.plot(Field,Mag_4K,lw=1.,color='r')

	Field = np.array(pd.read_excel(open(folder_1+'/'+compound_1+'_SQUID.xlsx'), 
	                'Sheet1', index_col=None, na_values=['NA'], usecols = "M"))
	Mag_2K = np.array(pd.read_excel(open(folder_1+'/'+compound_1+'_SQUID.xlsx'), 
	                'Sheet1', index_col=None, na_values=['NA'],   usecols = "R"))
	Mag_4K = np.array(pd.read_excel(open(folder_1+'/'+compound_1+'_SQUID.xlsx'), 
	                'Sheet1', index_col=None, na_values=['NA'],   usecols = "S"))

	ax1.plot(Field,Mag_2K,lw=0.,c='b', marker='o', markerfacecolor='None', markeredgecolor='b', markersize=4,label='2 K')
	ax1.plot(Field,Mag_4K,lw=0.,c='r', marker='o', markerfacecolor='None', markeredgecolor='r', markersize=4,label='4 K')

	Field  = []
	Mag_2K = []
	Mag_4K = []
	with open(folder_2+'/'+compound_2+'.out', 'r') as f:
		for line in f:
			if line.find('HIGH-FIELD POWDER MAGNETIZATION') != -1:
				for i in xrange(6):
					line = next(f)
				while True:
					Field.append( float(line.split()[0]) )
					Mag_2K.append( float(line.split()[6]) )
					Mag_4K.append( float(line.split()[8]) )
					line = next(f)	
					if line.find('--|---------------|--') != -1:
						break

	ax2.plot(Field,Mag_2K,lw=1.,color='b')
	ax2.plot(Field,Mag_4K,lw=1.,color='r')

	Field = np.array(pd.read_excel(open(folder_2+'/'+compound_2+'_SQUID.xlsx'), 
	                'Sheet1', index_col=None, na_values=['NA'], usecols = "M"))
	Mag_2K = np.array(pd.read_excel(open(folder_2+'/'+compound_2+'_SQUID.xlsx'), 
	               'Sheet1', index_col=None, na_values=['NA'],   usecols = "R"))
	Mag_4K = np.array(pd.read_excel(open(folder_2+'/'+compound_2+'_SQUID.xlsx'), 
	               'Sheet1', index_col=None, na_values=['NA'],   usecols = "S"))

	ax2.plot(Field,Mag_2K,lw=0.,c='b', marker='o', markerfacecolor='None', markeredgecolor='b', markersize=4,label='2 K')
	ax2.plot(Field,Mag_4K,lw=0.,c='r', marker='o', markerfacecolor='None', markeredgecolor='r', markersize=4,label='4 K')

	ax1.legend(loc=4,fontsize='10', numpoints = 1, ncol=1, frameon=False)
	ax2.legend(loc=4,fontsize='10', numpoints = 1, ncol=1, frameon=False)
	ax1.set_xlabel('$Field\ (Oe)$')
	ax2.set_xlabel('$Field\ (Oe)$')
	ax1.set_ylabel('$Magnetisation\ (B.M.)$')
	ax1.set_xlim([-0.5,6.5])
	plt.savefig('comparison_mag_Tb.png', dpi=300)
	plt.show()

	return
	

def plot_hyst(folder, compound):

	fig, (ax1) = plt.subplots( 1, sharex=True, sharey=True, figsize=(8.1,5.85))

	Field  = []
	Moment = []
	
	temperatures = np.array([2,4,6,8,10])
	pal = sns.color_palette("coolwarm", len(temperatures))

	Field  = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'hyst', header=None, na_values=['NA'], usecols = "C", skiprows=31) )

	Moment = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'hyst', header=None, na_values=['NA'], usecols = "E", skiprows=31) )

	Field  = np.reshape(Field ,(len(temperatures),124))
	Moment = np.reshape(Moment,(len(temperatures),124))
	for i,t in enumerate(temperatures):
		plt.plot(Field[i], Moment[i], lw=0.5, marker='o',
		         markerfacecolor='w',markeredgecolor=pal[i],c=pal[i],markersize=5, label=str(t)+' K')
	
	plt.xlabel('$Field\ (Oe)$')
	plt.ylabel('$Moment (emu)$')
	plt.legend(loc=0,fontsize='10', numpoints = 1, ncol=len(temperatures)/2, frameon=False)
	return 


def plot_ZFC_FC(folder, compound):

	fig, (ax1) = plt.subplots( 1, sharex=True, sharey=True, figsize=(8.1,5.85))

	Temp_ZFC   = []
	Moment_ZFC = []
	Temp_FC    = []
	Moment_FC  = []
	
	Fields = np.array([1000,500])

	Temp_ZFC   = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'ZFC-FC', header=None, na_values=['NA'], usecols = "D", skiprows=31) )

	Moment_ZFC = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'ZFC-FC', header=None, na_values=['NA'], usecols = "F", skiprows=31) )

	Temp_ZFC   = np.reshape(Temp_ZFC,   (len(Fields),34))
	Moment_ZFC = np.reshape(Moment_ZFC, (len(Fields),34))

	Temp_FC   = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'ZFC-FC', header=None, na_values=['NA'], usecols = "H", skiprows=31) )

	Moment_FC = np.array( pd.read_excel(open(folder+'/'+compound+'_SQUID.xlsx'), 
	               'ZFC-FC', header=None, na_values=['NA'], usecols = "J", skiprows=31) )

	points_FC = np.array([44,34])
	Temp_FC   = [ Temp_FC[sum(points_FC[:i]):sum(points_FC[:i+1])] for i in range(len(points_FC)) ]
	Moment_FC = [ Moment_FC[sum(points_FC[:i]):sum(points_FC[:i+1])] for i in range(len(points_FC)) ]
	cl = [['r','g'],['b','purple']]
	
	for i,t in enumerate(Fields):
		plt.plot(Temp_ZFC[i], Moment_ZFC[i], lw=0.5, marker='s',markerfacecolor='w',
                         markeredgecolor=cl[i][0],c=cl[i][0],markersize=6, label=str(t)+' Oe')
		plt.plot(Temp_FC[i], Moment_FC[i], lw=0.5, marker='o', markerfacecolor='w',
                         markeredgecolor=cl[i][1],c=cl[i][1],markersize=6, label=str(t)+' Oe')
	
	plt.xlim([0,100])
	plt.xlabel('$Temperature\ (K)$')
	plt.ylabel('$\chi_{M}\ (cm^{-3}Kmol^{-1})$')
	plt.legend(loc=0,fontsize='10', numpoints = 1, ncol=len(Fields)/2, frameon=False)
	return 

######################################   END OF FUNCTIONS   ###########################################

'''
# ------------------------------------- Chi T --------------------------------------------------------
fig, (ax1,ax2) = plt.subplots( 2,1, sharex=True, sharey=True, figsize=(4.2,5.85))

#plot_ChiT(folder,compound,axis, color, label):
plot_ChiT('TbBH4', 'TbBH4', ax1, 'r', '1')
plot_ChiT('TbBArF', 'TbBArF_def', ax2, 'r', '2')
ax1.set_ylabel(r'$\chi T\ (cm^{3}mol^{-1}K)$')
ax2.set_ylabel(r'$\chi T\ (cm^{3}mol^{-1}K)$')
ax2.set_xlabel('$Temperature\ (K)$')
fig.tight_layout()

ax1.legend(loc=0,fontsize='10', numpoints = 1, ncol=2, frameon=False)
ax1.set_ylim([0,12])
plt.savefig('comparison_ChiT_Tb.png', dpi=300)
plt.show()
plt.close('all')
exit()
'''

# ------------------------------------- Mag --------------------------------------------------------
#plot_Mag(folder_1,compound_1,folder_2,compound_2):
plot_Mag('TbBH4', 'TbBH4',   'TbBArF', 'TbBArF')
plt.close('all')

'''
# ------------------------------------- Hyst --------------------------------------------------------
#plot_hyst('TbBArF', 'TbBArF')
plot_hyst('TbBArF', 'TbBArF_def')
plt.savefig('hyst_TbBArF.png', dpi=300)
plt.show()
plt.close('all')

# ------------------------------------- ZFC-FC --------------------------------------------------------
#plot_ZFC_FC('TbBArF', 'TbBArF')
plot_ZFC_FC('TbBArF', 'TbBArF_def')
plt.savefig('ZFC-FC_TbBArF.png', dpi=300)
plt.show()
'''
